@@ -36,9 +36,7 @@ describe 'quoted paths' do
 
     describe file("#{basedir}/concat test/foo") do
       it { should be_file }
-      it("should contain string1\nstring2", :unless => (fact('osfamily') == 'Solaris')) {
-        should contain "string1\nstring2"
-      }
+      its(:content) { should match /string1string2/ }
     end
   end
 end
